[PATCH v2 4/7] use 'committish' instead of 'commit-ish'

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Replace all instances of 'commit-ish' with 'committish':
  * to standardize on a single spelling (the documentation contained a
    mix of 'committish' and 'commit-ish')
  * to be consistent with variable names (hyphens are not usually
    allowed in variable names)
  * to be consistent with 'treeish'
  * some search engines don't handle hyphens gracefully

Signed-off-by: Richard Hansen <rhansen@xxxxxxx>
---
 Documentation/git-rebase.txt        |  2 +-
 Documentation/git-rev-parse.txt     |  2 +-
 Documentation/git.txt               |  4 ++--
 builtin/revert.c                    |  4 ++--
 contrib/examples/git-reset.sh       |  2 +-
 contrib/examples/git-revert.sh      |  4 ++--
 po/de.po                            |  4 ++--
 po/fr.po                            |  4 ++--
 po/git.pot                          |  4 ++--
 po/sv.po                            |  4 ++--
 po/vi.po                            |  8 ++++----
 po/zh_CN.po                         |  4 ++--
 remote.c                            |  2 +-
 t/t1512-rev-parse-disambiguation.sh | 16 ++++++++--------
 14 files changed, 32 insertions(+), 32 deletions(-)

diff --git a/Documentation/git-rebase.txt b/Documentation/git-rebase.txt
index 6b2e1c8..f8ac62d 100644
--- a/Documentation/git-rebase.txt
+++ b/Documentation/git-rebase.txt
@@ -174,7 +174,7 @@ would result in the removal of commits F and G:
 
 This is useful if F and G were flawed in some way, or should not be
 part of topicA.  Note that the argument to --onto and the <upstream>
-parameter can be any valid commit-ish.
+parameter can be any valid committish.
 
 In case of conflict, 'git rebase' will stop at the first problematic commit
 and leave conflict markers in the tree.  You can use 'git diff' to locate
diff --git a/Documentation/git-rev-parse.txt b/Documentation/git-rev-parse.txt
index d068a65..56f643d 100644
--- a/Documentation/git-rev-parse.txt
+++ b/Documentation/git-rev-parse.txt
@@ -100,7 +100,7 @@ If you want to make sure that the output actually names an object in
 your object database and/or can be used as a specific type of object
 you require, you can add "^{type}" peeling operator to the parameter.
 For example, `git rev-parse "$VAR^{commit}"` will make sure `$VAR`
-names an existing object that is a commit-ish (i.e. a commit, or an
+names an existing object that is a committish (i.e. a commit, or an
 annotated tag that points at a commit).  To make sure that `$VAR`
 names an existing object of any type, `git rev-parse "$VAR^{object}"`
 can be used.
diff --git a/Documentation/git.txt b/Documentation/git.txt
index c07915b..9d9ae26 100644
--- a/Documentation/git.txt
+++ b/Documentation/git.txt
@@ -606,9 +606,9 @@ Identifier Terminology
 	operate on a <tree> object but automatically dereferences
 	<commit> and <tag> objects that point at a <tree>.
 
-<commit-ish>::
+<committish>::
 	Indicates a commit or tag object name.  A
-	command that takes a <commit-ish> argument ultimately wants to
+	command that takes a <committish> argument ultimately wants to
 	operate on a <commit> object but automatically dereferences
 	<tag> objects that point at a <commit>.
 
diff --git a/builtin/revert.c b/builtin/revert.c
index 1d2648b..9339816 100644
--- a/builtin/revert.c
+++ b/builtin/revert.c
@@ -19,13 +19,13 @@
  */
 
 static const char * const revert_usage[] = {
-	N_("git revert [options] <commit-ish>..."),
+	N_("git revert [options] <committish>..."),
 	N_("git revert <subcommand>"),
 	NULL
 };
 
 static const char * const cherry_pick_usage[] = {
-	N_("git cherry-pick [options] <commit-ish>..."),
+	N_("git cherry-pick [options] <committish>..."),
 	N_("git cherry-pick <subcommand>"),
 	NULL
 };
diff --git a/contrib/examples/git-reset.sh b/contrib/examples/git-reset.sh
index bafeb52..ac06274 100755
--- a/contrib/examples/git-reset.sh
+++ b/contrib/examples/git-reset.sh
@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2005, 2006 Linus Torvalds and Junio C Hamano
 #
-USAGE='[--mixed | --soft | --hard]  [<commit-ish>] [ [--] <paths>...]'
+USAGE='[--mixed | --soft | --hard]  [<committish>] [ [--] <paths>...]'
 SUBDIRECTORY_OK=Yes
 . git-sh-setup
 set_reflog_action "reset $*"
diff --git a/contrib/examples/git-revert.sh b/contrib/examples/git-revert.sh
index 6bf155c..6f1dd66 100755
--- a/contrib/examples/git-revert.sh
+++ b/contrib/examples/git-revert.sh
@@ -9,12 +9,12 @@ case "$0" in
 	test -t 0 && edit=-e
 	replay=
 	me=revert
-	USAGE='[--edit | --no-edit] [-n] <commit-ish>' ;;
+	USAGE='[--edit | --no-edit] [-n] <committish>' ;;
 *-cherry-pick* )
 	replay=t
 	edit=
 	me=cherry-pick
-	USAGE='[--edit] [-n] [-r] [-x] <commit-ish>'  ;;
+	USAGE='[--edit] [-n] [-r] [-x] <committish>'  ;;
 * )
 	echo >&2 "What are you talking about?"
 	exit 1 ;;
diff --git a/po/de.po b/po/de.po
index 00519b2..4cdb2aa 100644
--- a/po/de.po
+++ b/po/de.po
@@ -8742,7 +8742,7 @@ msgstr ""
 "erster Verwendung aus."
 
 #: builtin/revert.c:22
-msgid "git revert [options] <commit-ish>..."
+msgid "git revert [options] <committish>..."
 msgstr "git revert [Optionen] <Commit-Angabe>..."
 
 #: builtin/revert.c:23
@@ -8750,7 +8750,7 @@ msgid "git revert <subcommand>"
 msgstr "git revert <Unterkommando>"
 
 #: builtin/revert.c:28
-msgid "git cherry-pick [options] <commit-ish>..."
+msgid "git cherry-pick [options] <committish>..."
 msgstr "git cherry-pick [Optionen] <Commit-Angabe>..."
 
 #: builtin/revert.c:29
diff --git a/po/fr.po b/po/fr.po
index 8d74171..60046ee 100644
--- a/po/fr.po
+++ b/po/fr.po
@@ -8032,7 +8032,7 @@ msgid ""
 msgstr ""
 
 #: builtin/revert.c:22
-msgid "git revert [options] <commit-ish>..."
+msgid "git revert [options] <committish>..."
 msgstr ""
 
 #: builtin/revert.c:23
@@ -8040,7 +8040,7 @@ msgid "git revert <subcommand>"
 msgstr ""
 
 #: builtin/revert.c:28
-msgid "git cherry-pick [options] <commit-ish>..."
+msgid "git cherry-pick [options] <committish>..."
 msgstr ""
 
 #: builtin/revert.c:29
diff --git a/po/git.pot b/po/git.pot
index 928268f..d101f1b 100644
--- a/po/git.pot
+++ b/po/git.pot
@@ -8146,7 +8146,7 @@ msgid ""
 msgstr ""
 
 #: builtin/revert.c:22
-msgid "git revert [options] <commit-ish>..."
+msgid "git revert [options] <committish>..."
 msgstr ""
 
 #: builtin/revert.c:23
@@ -8154,7 +8154,7 @@ msgid "git revert <subcommand>"
 msgstr ""
 
 #: builtin/revert.c:28
-msgid "git cherry-pick [options] <commit-ish>..."
+msgid "git cherry-pick [options] <committish>..."
 msgstr ""
 
 #: builtin/revert.c:29
diff --git a/po/sv.po b/po/sv.po
index cdee340..e118303 100644
--- a/po/sv.po
+++ b/po/sv.po
@@ -8528,7 +8528,7 @@ msgstr ""
 "varianten."
 
 #: builtin/revert.c:22
-msgid "git revert [options] <commit-ish>..."
+msgid "git revert [options] <committish>..."
 msgstr "git revert [flaggor] <incheckning-igt>..."
 
 #: builtin/revert.c:23
@@ -8536,7 +8536,7 @@ msgid "git revert <subcommand>"
 msgstr "git revert <underkommando>"
 
 #: builtin/revert.c:28
-msgid "git cherry-pick [options] <commit-ish>..."
+msgid "git cherry-pick [options] <committish>..."
 msgstr "git cherry-pick [flaggor] <incheckning-igt>..."
 
 #: builtin/revert.c:29
diff --git a/po/vi.po b/po/vi.po
index ebc079c..263873c 100644
--- a/po/vi.po
+++ b/po/vi.po
@@ -8673,16 +8673,16 @@ msgstr ""
 "Chạy lệnh \"git rev-parse --parseopt -h\" để có thêm thông tin về cách dùng."
 
 #: builtin/revert.c:22
-msgid "git revert [options] <commit-ish>..."
-msgstr "git revert [các-tùy-chọn] <commit-ish>..."
+msgid "git revert [options] <committish>..."
+msgstr "git revert [các-tùy-chọn] <committish>..."
 
 #: builtin/revert.c:23
 msgid "git revert <subcommand>"
 msgstr "git revert <lệnh-con>"
 
 #: builtin/revert.c:28
-msgid "git cherry-pick [options] <commit-ish>..."
-msgstr "git cherry-pick [các-tùy-chọn] <commit-ish>..."
+msgid "git cherry-pick [options] <committish>..."
+msgstr "git cherry-pick [các-tùy-chọn] <committish>..."
 
 #: builtin/revert.c:29
 msgid "git cherry-pick <subcommand>"
diff --git a/po/zh_CN.po b/po/zh_CN.po
index 497d847..66e2e60 100644
--- a/po/zh_CN.po
+++ b/po/zh_CN.po
@@ -8496,7 +8496,7 @@ msgstr ""
 "初次使用时执行 \"git rev-parse --parseopt -h\" 来获得更多信息。"
 
 #: builtin/revert.c:22
-msgid "git revert [options] <commit-ish>..."
+msgid "git revert [options] <committish>..."
 msgstr "git revert [选项] <提交号>..."
 
 #: builtin/revert.c:23
@@ -8504,7 +8504,7 @@ msgid "git revert <subcommand>"
 msgstr "git revert <子命令>"
 
 #: builtin/revert.c:28
-msgid "git cherry-pick [options] <commit-ish>..."
+msgid "git cherry-pick [options] <committish>..."
 msgstr "git cherry-pick [选项] <提交号>..."
 
 #: builtin/revert.c:29
diff --git a/remote.c b/remote.c
index efcba93..9099cb3 100644
--- a/remote.c
+++ b/remote.c
@@ -1663,7 +1663,7 @@ int ref_newer(const unsigned char *new_sha1, const unsigned char *old_sha1)
 	int found = 0;
 
 	/*
-	 * Both new and old must be commit-ish and new is descendant of
+	 * Both new and old must be committish and new is descendant of
 	 * old.  Otherwise we require --force.
 	 */
 	o = deref_tag(parse_object(old_sha1), NULL, 0);
diff --git a/t/t1512-rev-parse-disambiguation.sh b/t/t1512-rev-parse-disambiguation.sh
index 840bb6e..4b311c7 100755
--- a/t/t1512-rev-parse-disambiguation.sh
+++ b/t/t1512-rev-parse-disambiguation.sh
@@ -86,8 +86,8 @@ test_expect_success 'first commit' '
 	git commit -m a2onsxbvj
 '
 
-test_expect_success 'disambiguate commit-ish' '
-	# feed commit-ish in an unambiguous way
+test_expect_success 'disambiguate committish' '
+	# feed committish in an unambiguous way
 	git rev-parse --verify 0000000000e4f^{commit} &&
 
 	# ambiguous at the object name level, but there is only one
@@ -104,7 +104,7 @@ test_expect_success 'disambiguate commit' '
 	test $(git rev-parse $commit^) = $(git rev-parse 0000000000e4f)
 '
 
-test_expect_success 'log name1..name2 takes only commit-ishes on both ends' '
+test_expect_success 'log name1..name2 takes only committishes on both ends' '
 	# These are underspecified from the prefix-length point of view
 	# to disambiguate the commit with other objects, but there is only
 	# one commit that has 00000* prefix at this point.
@@ -116,19 +116,19 @@ test_expect_success 'log name1..name2 takes only commit-ishes on both ends' '
 	git log 000000000...
 '
 
-test_expect_success 'rev-parse name1..name2 takes only commit-ishes on both ends' '
+test_expect_success 'rev-parse name1..name2 takes only committishes on both ends' '
 	# Likewise.
 	git rev-parse 000000000..000000000 &&
 	git rev-parse ..000000000 &&
 	git rev-parse 000000000..
 '
 
-test_expect_success 'git log takes only commit-ish' '
+test_expect_success 'git log takes only committish' '
 	# Likewise.
 	git log 000000000
 '
 
-test_expect_success 'git reset takes only commit-ish' '
+test_expect_success 'git reset takes only committish' '
 	# Likewise.
 	git reset 000000000
 '
@@ -138,7 +138,7 @@ test_expect_success 'first tag' '
 	git tag -a -m j7cp83um v1.0.0
 '
 
-test_expect_failure 'two semi-ambiguous commit-ish' '
+test_expect_failure 'two semi-ambiguous committish' '
 	# At this point, we have a tag 0000000000f8f that points
 	# at a commit 0000000000e4f, and a tree and a blob that
 	# share 0000000000 prefix with these tag and commit.
@@ -249,7 +249,7 @@ test_expect_success 'parse describe name not ignoring ambiguity' '
 	test_must_fail git rev-parse --verify v1.0.0-1-g000000000
 '
 
-test_expect_success 'ambiguous commit-ish' '
+test_expect_success 'ambiguous committish' '
 	# Now there are many commits that begin with the
 	# common prefix, none of these should pick one at
 	# random.  They all should result in ambiguity errors.
-- 
1.8.4

--
To unsubscribe from this list: send the line "unsubscribe git" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html




[Index of Archives]     [Linux Kernel Development]     [Gcc Help]     [IETF Annouce]     [DCCP]     [Netdev]     [Networking]     [Security]     [V4L]     [Bugtraq]     [Yosemite]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux SCSI]     [Fedora Users]